@@ -122,3 +122,13 @@ class Prediction(APIResource):
         url = '/'.join([cls._CLASS_PREFIX, str(pred_id), 'perturbations'])
         response = requester.post(url=url, body={"features": features, "target_value": target_value}, api_key=api_key)
         return response
+
+    @classmethod
+    def get_perturbations_download_link(cls, pred_id: int, features: str = None,  api_key: str = None) -> WhatifyResponse:
+        requester = APIRequestor()
+        url = '/'.join([cls._CLASS_PREFIX, str(pred_id), 'perturbations_link'])
+        data = {
+            "features": features
+        }
+        response = requester.post(url=url, body=data, api_key=api_key)
+        return response
